@@ -15,9 +15,9 @@ from applitools.common.match import MatchResult
 from applitools.common.metadata import AppEnvironment, SessionStartInfo
 from applitools.common.server import FailureReports, SessionType
 from applitools.common.test_results import TestResults
+from applitools.common.ultrafastgrid import RenderingInfo
 from applitools.common.utils import ABC, argument_guard
 from applitools.common.utils.compat import raise_from
-from applitools.common.ultrafastgrid import RenderingInfo
 from applitools.core.capture import AppOutputProvider, AppOutputWithScreenshot
 from applitools.core.cut import (
     FixedCutProvider,
@@ -36,12 +36,13 @@ from .scaling import FixedScaleProvider, NullScaleProvider, ScaleProvider
 from .server_connector import ServerConnector
 
 if typing.TYPE_CHECKING:
-    from applitools.common.utils.custom_types import ViewPort, UserInputs, Num
-    from applitools.core.fluent.check_settings import CheckSettings
-    from applitools.common.capture import EyesScreenshot
-    from applitools.common import MatchLevel
     from typing import Optional, Text, Union
 
+    from applitools.common import MatchLevel
+    from applitools.common.capture import EyesScreenshot
+    from applitools.common.utils.custom_types import Num, UserInputs, ViewPort
+    from applitools.core.fluent.check_settings import CheckSettings
+
 __all__ = ("EyesBase",)
 
 
@@ -87,9 +88,7 @@ class _EyesBaseAbstract(ABC):
     @abc.abstractmethod
     def _set_viewport_size(self, size):
         # type: (ViewPort) -> None
-        """
-
-        """
+        """"""
 
     @property
     @abc.abstractmethod
@@ -685,9 +684,14 @@ class EyesBase(
         """
 
     def _check_window_base(
-        self, region_provider, tag=None, ignore_mismatch=False, check_settings=None
+        self,
+        region_provider,  # type: RegionProvider
+        tag=None,  # type: Optional[Text]
+        ignore_mismatch=False,  # type: bool
+        check_settings=None,  # type: CheckSettings
+        source=None,  # type: Optional[Text]
     ):
-        # type: (RegionProvider, Optional[Text], bool, CheckSettings) -> MatchResult
+        # type: (...) -> MatchResult
         if self.configure.is_disabled:
             logger.info("check_window(%s): ignored (disabled)" % tag)
             return MatchResult(as_expected=True)
@@ -697,7 +701,7 @@ class EyesBase(
         self._before_match_window()
 
         tag = tag if tag is not None else ""
-        result = self._match_window(region_provider, tag, check_settings)
+        result = self._match_window(region_provider, tag, check_settings, source)
 
         if not ignore_mismatch:
             del self._user_inputs[:]
@@ -740,8 +744,8 @@ class EyesBase(
             )
             return None
 
-    def _match_window(self, region_provider, tag, check_settings):
-        # type: (RegionProvider, Text, CheckSettings) -> MatchResult
+    def _match_window(self, region_provider, tag, check_settings, source):
+        # type: (RegionProvider, Text, CheckSettings, Optional[Text]) -> MatchResult
         # Update retry timeout if it wasn't specified.
         retry_timeout_ms = -1  # type: Num
         if check_settings:
@@ -757,6 +761,7 @@ class EyesBase(
             self._should_match_once_on_timeout,
             check_settings,
             retry_timeout_ms,
+            source,
         )
         return result
 
