@@ -6,6 +6,7 @@ from applitools.common.utils import ABC, iteritems
 
 class EyesRunner(ABC):
     def __init__(self):
+        logger.open_()
         self._batch_server_connectors = {}
 
     @abstractmethod
@@ -15,4 +16,7 @@ class EyesRunner(ABC):
     def get_all_test_results(self, should_raise_exception=True):
         # type: (bool) -> TestResultsSummary
         logger.debug("get_all_test_results({}) called".format(should_raise_exception))
-        return self._get_all_test_results_impl(should_raise_exception)
+        summary = self._get_all_test_results_impl(should_raise_exception)
+        logger.debug(str(summary))
+        logger.close()
+        return summary
